# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata


class GetPronunciationDictionaryWithRulesResponseModelRulesItem_Alias(UncheckedBaseModel):
    type: typing.Literal["alias"] = "alias"
    string_to_replace: str
    case_sensitive: typing.Optional[bool] = None
    word_boundaries: typing.Optional[bool] = None
    alias: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class GetPronunciationDictionaryWithRulesResponseModelRulesItem_Phoneme(UncheckedBaseModel):
    type: typing.Literal["phoneme"] = "phoneme"
    string_to_replace: str
    case_sensitive: typing.Optional[bool] = None
    word_boundaries: typing.Optional[bool] = None
    phoneme: str
    alphabet: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


GetPronunciationDictionaryWithRulesResponseModelRulesItem = typing_extensions.Annotated[
    typing.Union[
        GetPronunciationDictionaryWithRulesResponseModelRulesItem_Alias,
        GetPronunciationDictionaryWithRulesResponseModelRulesItem_Phoneme,
    ],
    UnionMetadata(discriminant="type"),
]
