# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .guardrail_execution_mode import GuardrailExecutionMode


class CustomGuardrailConfig(UncheckedBaseModel):
    """
    Single custom guardrail configuration
    """

    is_enabled: typing.Optional[bool] = None
    name: str = pydantic.Field()
    """
    User-facing name for this guardrail
    """

    prompt: str = pydantic.Field()
    """
    Instruction describing what to block, e.g. 'don't talk about politics'
    """

    execution_mode: typing.Optional[GuardrailExecutionMode] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
