# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DependentUnknownAgentIdentifier(UncheckedBaseModel):
    """
    A model that represents an agent dependent on a knowledge base/tools
    to which the user has no direct access.
    """

    referenced_resource_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    If the agent is a transitive dependent, contains IDs of the resources that the agent depends on directly.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
