# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .body_text_to_speech_full_apply_text_normalization import BodyTextToSpeechFullApplyTextNormalization
    from .body_text_to_speech_full_with_timestamps_apply_text_normalization import (
        BodyTextToSpeechFullWithTimestampsApplyTextNormalization,
    )
    from .body_text_to_speech_stream_apply_text_normalization import BodyTextToSpeechStreamApplyTextNormalization
    from .body_text_to_speech_stream_with_timestamps_apply_text_normalization import (
        BodyTextToSpeechStreamWithTimestampsApplyTextNormalization,
    )
    from .text_to_speech_convert_request_output_format import TextToSpeechConvertRequestOutputFormat
    from .text_to_speech_convert_with_timestamps_request_output_format import (
        TextToSpeechConvertWithTimestampsRequestOutputFormat,
    )
    from .text_to_speech_stream_request_output_format import TextToSpeechStreamRequestOutputFormat
    from .text_to_speech_stream_with_timestamps_request_output_format import (
        TextToSpeechStreamWithTimestampsRequestOutputFormat,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "BodyTextToSpeechFullApplyTextNormalization": ".body_text_to_speech_full_apply_text_normalization",
    "BodyTextToSpeechFullWithTimestampsApplyTextNormalization": ".body_text_to_speech_full_with_timestamps_apply_text_normalization",
    "BodyTextToSpeechStreamApplyTextNormalization": ".body_text_to_speech_stream_apply_text_normalization",
    "BodyTextToSpeechStreamWithTimestampsApplyTextNormalization": ".body_text_to_speech_stream_with_timestamps_apply_text_normalization",
    "TextToSpeechConvertRequestOutputFormat": ".text_to_speech_convert_request_output_format",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat": ".text_to_speech_convert_with_timestamps_request_output_format",
    "TextToSpeechStreamRequestOutputFormat": ".text_to_speech_stream_request_output_format",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat": ".text_to_speech_stream_with_timestamps_request_output_format",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BodyTextToSpeechFullApplyTextNormalization",
    "BodyTextToSpeechFullWithTimestampsApplyTextNormalization",
    "BodyTextToSpeechStreamApplyTextNormalization",
    "BodyTextToSpeechStreamWithTimestampsApplyTextNormalization",
    "TextToSpeechConvertRequestOutputFormat",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat",
    "TextToSpeechStreamRequestOutputFormat",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat",
]
