# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2
from ....core.unchecked_base_model import UncheckedBaseModel, UnionMetadata


class BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_Coached(UncheckedBaseModel):
    type: typing.Literal["coached"] = "coached"
    memory_base_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_None(UncheckedBaseModel):
    type: typing.Literal["none"] = "none"
    memory_base_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings = typing_extensions.Annotated[
    typing.Union[
        BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_Coached,
        BodyCreateAgentV1ConvaiAgentsCreatePostCoachingSettings_None,
    ],
    UnionMetadata(discriminant="type"),
]
